@@ -103,7 +103,11 @@ static void poppler_error_handler(void *data, ErrorCategory category, pdf::Offse
 
 pdf::Environment::Environment()
 {
-  globalParams = new GlobalParams();
+#if POPPLER_VERSION >= 8300
+  globalParams = std::unique_ptr<GlobalParams>(new GlobalParams);
+#else
+  globalParams = new GlobalParams;
+#endif
   setErrorCallback(poppler_error_handler, nullptr);
 }
 
@@ -499,12 +503,15 @@ bool pdf::get_glyph(splash::Splash *splash, splash::Font *font,
 void pdf::Renderer::convert_path(pdf::gfx::State *state, splash::Path &splash_path)
 {
   /* Source was copied from <poppler/SplashOutputDev.c>. */
-  pdf::gfx::Subpath *subpath;
-  pdf::gfx::Path *path = state->getPath();
+  // for POPPLER_VERSION >= 8300:
+  //   const pdf::gfx::Path *path
+  auto path = state->getPath();
   int n_subpaths = path->getNumSubpaths();
   for (int i = 0; i < n_subpaths; i++)
   {
-    subpath = path->getSubpath(i);
+    // for POPPLER_VERSION >= 8300:
+    //   const pdf::gfx::Subpath *subpath
+    auto subpath = path->getSubpath(i);
     if (subpath->getNumPoints() > 0)
     {
       double x1, y1, x2, y2, x3, y3;
