@@ -335,8 +335,13 @@ public:
     return;
   }
 
+#if POPPLER_VERSION >= 8200
+  void drawImage(pdf::gfx::State *state, pdf::Object *object, pdf::Stream *stream, int width, int height,
+    pdf::gfx::ImageColorMap *color_map, bool interpolate, const int *mask_colors, bool inline_image)
+#else
   void drawImage(pdf::gfx::State *state, pdf::Object *object, pdf::Stream *stream, int width, int height,
     pdf::gfx::ImageColorMap *color_map, bool interpolate, int *mask_colors, bool inline_image)
+#endif
   {
     if (is_foreground_color_map(color_map) || config.no_render)
     {
@@ -344,7 +349,7 @@ public:
       return;
     }
     Renderer::drawImage(state, object, stream, width, height, color_map,
-        interpolate, mask_colors, inline_image);
+      interpolate, mask_colors, inline_image);
   }
 
   void drawMaskedImage(pdf::gfx::State *state, pdf::Object *object, pdf::Stream *stream, int width, int height,
@@ -378,8 +383,13 @@ public:
 
   bool interpretType3Chars() { return false; }
 
+#if POPPLER_VERSION >= 8200
+  void drawChar(pdf::gfx::State *state, double x, double y, double dx, double dy, double origin_x, double origin_y,
+    CharCode code, int n_bytes, const Unicode *unistr, int length)
+#else
   void drawChar(pdf::gfx::State *state, double x, double y, double dx, double dy, double origin_x, double origin_y,
     CharCode code, int n_bytes, Unicode *unistr, int length)
+#endif
   {
     double pox, poy, pdx, pdy, px, py, pw, ph;
     x -= origin_x; y -= origin_y;
